#include <Adafruit_MPU6050.h>
#include <Adafruit_Sensor.h>
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

Adafruit_MPU6050 mpu;
Adafruit_SSD1306 display(128, 32, &Wire);

void setup(void) {
  Serial.begin(115200);
  while (!Serial) delay(10);

  // Initialize MPU6050
  if (!mpu.begin()) {
    Serial.println("Failed to find MPU6050 chip");
    while (1) delay(10);
  }

  // Initialize OLED display
  if (!display.begin(SSD1306_SWITCHCAPVCC, 0x3C)) {
    Serial.println(F("SSD1306 allocation failed"));
    while (1);
  }
  display.display();
  delay(2000);  // Pause for 2 seconds

  // Set up MPU6050 settings
  mpu.setAccelerometerRange(MPU6050_RANGE_8_G);
  mpu.setGyroRange(MPU6050_RANGE_500_DEG);
  mpu.setFilterBandwidth(MPU6050_BAND_21_HZ);
}

void loop() {
  sensors_event_t a, g, temp;
  mpu.getEvent(&a, &g, &temp);

  // Clear the display
  display.clearDisplay();

  // Display acceleration values
  display.setTextSize(1);
  display.setTextColor(SSD1306_WHITE);
  display.setCursor(0, 0);
  display.print("Accel X: "); display.print(a.acceleration.x); display.println(" m/s^2");
  display.print("Accel Y: "); display.print(a.acceleration.y); display.println(" m/s^2");
  display.print("Accel Z: "); display.print(a.acceleration.z); display.println(" m/s^2");

  // Display rotation values
  display.print("Gyro X: "); display.print(g.gyro.x); display.println(" rad/s");
  display.print("Gyro Y: "); display.print(g.gyro.y); display.println(" rad/s");
  display.print("Gyro Z: "); display.print(g.gyro.z); display.println(" rad/s");

  // Display temperature
  display.print("Temp: "); display.print(temp.temperature); display.println(" C");

  // Update the display with the new data
  display.display();

  // Delay before next reading
  delay(500);
}
